searchData={"items":[{"type":"module","title":"PCA9641","doc":"PCA9641 Driver for Elixir using Wafer.\n\nThe PCA9641 I2C bus arbiter allows two I2C masters (eg Raspberry Pis) to be\nconnected to the same downstream I2C bus.  The chip decides which master has\naccess to the bus based on it's own internal state machine.\n\nThe device also contains an interrupt input pin which can be used for\ndownstream devices to signal interrupts and be passed to the two interrupt\noutputs connected to the two masters.\n\n##  Examples\n\nConnecting to the device using Elixir Circuits.\n\n  iex> {:ok, i2c_conn} = Wafer.Driver.Circuits.I2C.acquire(bus_name: \"i2c-1\", address: 0x70)\n  ...> {:ok, int_conn} = Wafer.Driver.Circuits.GPIO.acquire(pin: 7, direction: :in)\n  ...> {:ok, conn} = PCA9641.acquire(conn: i2c_conn, int_pin: int_conn)","ref":"PCA9641.html"},{"type":"function","title":"PCA9641.abandon_downstream_bus/1","doc":"Abandon the downstream bus.","ref":"PCA9641.html#abandon_downstream_bus/1"},{"type":"function","title":"PCA9641.acquire/1","doc":"Acquire a connection to the PCA9641 device using the passed in I2C connection.","ref":"PCA9641.html#acquire/1"},{"type":"function","title":"Options: - PCA9641.acquire/1","doc":"- `conn` (required) an I2C connection, probably from `ElixirALE.I2C` or\n    `Circuits.I2C`.\n  - `int_pin` a (optional) GPIO connection for the interrupt pin  This should\n    be already set to direction `:in`.","ref":"PCA9641.html#acquire/1-options"},{"type":"function","title":"PCA9641.bus_connect/2","doc":"BUS_CONNECT\n\nConnectivity between master and downstream bus; the internal switch connects\nI2C-bus from master to downstream bus only if LOCK_GRANT = 1.\n\n- `false` -> Do not connect I2C-bus from master to downstream bus.\n- `true` -> Connect downstream bus; the internal switch is closed only if LOCK_GRANT = 1.","ref":"PCA9641.html#bus_connect/2"},{"type":"function","title":"PCA9641.bus_connect?/1","doc":"BUS_CONNECT\n\nConnectivity between master and downstream bus; the internal switch connects\nI2C-bus from master to downstream bus only if LOCK_GRANT = 1.\n\n- `false` -> Do not connect I2C-bus from master to downstream bus.\n- `true` -> Connect downstream bus; the internal switch is closed only if LOCK_GRANT = 1.","ref":"PCA9641.html#bus_connect?/1"},{"type":"function","title":"PCA9641.bus_hung?/1","doc":"BUS_HUNG\n\nThis is a read-only status register bit. If this register bit is ‘0’, it\nindicates the bus is in normal condition. If this bit is ‘1’, it indicates the\nbus is hung. The hung bus means SDA signal is LOW and SCL signal does not\ntoggle for more than 500 ms or SCL is LOW for 500 ms.\n\n- `false` -> Normal operation.\n- `true` -> Downstream bus hung; when SDA signal is LOW and SCL signal does\n  not toggle for more than 500 ms or SCL is LOW for 500 ms.","ref":"PCA9641.html#bus_hung?/1"},{"type":"function","title":"PCA9641.bus_hung_interrupt?/1","doc":"BUS_HUNG_INT\n\nIndicates to both masters that SDA signal is LOW and SCL signal does not\ntoggle for more than 500 ms or SCL is LOW for 500 ms.\n\n- `false` -> No interrupt generated; normal operation.\n- `true` -> Interrupt generated; downstream bus cannot recover; when SDA\n  signal is LOW and SCL signal does not toggle for more than 500 ms or SCL is\n  LOW for 500 ms,","ref":"PCA9641.html#bus_hung_interrupt?/1"},{"type":"function","title":"PCA9641.bus_hung_interrupt_enabled?/1","doc":"BUS_HUNG_MSK\n\n- `false` -> Enable output interrupt when BUS_HUNG function is set.\n- `true` -> Disable output interrupt when BUS_HUNG function is set.","ref":"PCA9641.html#bus_hung_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.bus_init/2","doc":"BUS_INIT\n\nBus initialization for PCA9641 sends one clock out and checks SDA signal. If\nSDA is HIGH, PCA9641 sends a ‘not acknowledge’ and a STOP condition. The\nBUS_INIT function is completed. If SDA is LOW, PCA9641 sends other clock out\nand checks SDA again. The PCA9641 will send out 9 clocks (maximum), and if SDA\nis still LOW, PCA9641 determines the bus initialization has failed.\n\n- `false` -> Normal operation.\n- `true` -> Start initialization on next bus connect function to downstream\n  bus.","ref":"PCA9641.html#bus_init/2"},{"type":"function","title":"PCA9641.bus_init?/1","doc":"BUS_INIT\n\nBus initialization for PCA9641 sends one clock out and checks SDA signal. If\nSDA is HIGH, PCA9641 sends a ‘not acknowledge’ and a STOP condition. The\nBUS_INIT function is completed. If SDA is LOW, PCA9641 sends other clock out\nand checks SDA again. The PCA9641 will send out 9 clocks (maximum), and if SDA\nis still LOW, PCA9641 determines the bus initialization has failed.\n\n- `false` -> Normal operation.\n- `true` -> Start initialization on next bus connect function to downstream\n  bus.","ref":"PCA9641.html#bus_init?/1"},{"type":"function","title":"PCA9641.bus_initialisation_failed?/1","doc":"BUS_INIT_FAIL\n\nThis is a read-only status register bit. If this register bit is ‘0’, it\nindicates the bus initialization function has passed. The downstream bus is in\nidle mode (SCL and SDA are HIGH). If this register bit is ‘1’, it indicates\nthe bus initialization function has failed. The SDA signal could be stuck LOW.\n\n- `false` -> Normal operation.\n- `true` -> Bus initialization has failed. SDA still LOW, the downstream bus\n  cannot recover.","ref":"PCA9641.html#bus_initialisation_failed?/1"},{"type":"function","title":"PCA9641.bus_lost_interrupt?/1","doc":"BUS_LOST_INT\n\nIndicates the master has involuntarily lost the ownership of the downstream\nbus.\n\n- `false` -> No interrupt generated; this master is controlling the downstream\n  bus.\n- `true` -> Interrupt generated; this master has involuntarily lost the\n  control of the downstream bus.","ref":"PCA9641.html#bus_lost_interrupt?/1"},{"type":"function","title":"PCA9641.bus_lost_interrupt_enabled?/1","doc":"BUS_LOST_MSK\n\n- `false` -> Enable output interrupt when BUS_LOST function is set.\n- `true` -> Disable output interrupt when BUS_LOST function is set.","ref":"PCA9641.html#bus_lost_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.downstream_disconnect_on_timeout/2","doc":"SMBUS_DIS\n\nWhen PCA9641 detects an SMBus time-out, if this bit is set, PCA9641 will\ndisconnect I2C-bus from master to downstream bus.\n\n- `false` -> Normal operation.\n- `true` -> Connectivity between master and downstream bus will be\n  disconnected upon detecting an SMBus time-out condition.","ref":"PCA9641.html#downstream_disconnect_on_timeout/2"},{"type":"function","title":"PCA9641.downstream_disconnect_on_timeout?/1","doc":"SMBUS_DIS\n\nWhen PCA9641 detects an SMBus time-out, if this bit is set, PCA9641 will\ndisconnect I2C-bus from master to downstream bus.\n\n- `false` -> Normal operation.\n- `true` -> Connectivity between master and downstream bus will be\n  disconnected upon detecting an SMBus time-out condition.","ref":"PCA9641.html#downstream_disconnect_on_timeout?/1"},{"type":"function","title":"PCA9641.idle_timer_disconnect/2","doc":"IDLE_TIMER_DIS\n\nAfter RES_TIME is expired, I2C-bus idle for more than 100 ms, PCA9641 will\ndisconnect master from downstream bus and takes away its grant if this\nregister bit is enabled. This IDLE_TIMER_DIS function also applies when there\nis a grant of a request with zero value on RES_TIME.\n\n- `false` -> Normal operation.\n- `true` -> Enable 100 ms idle timer. After reserve timer expires or if\n  reserve timer is disabled, if the downstream bus is idle for more than 100\n  ms, the connection between master and downstream bus will be disconnected.","ref":"PCA9641.html#idle_timer_disconnect/2"},{"type":"function","title":"PCA9641.idle_timer_disconnect?/1","doc":"IDLE_TIMER_DIS\n\nAfter RES_TIME is expired, I2C-bus idle for more than 100 ms, PCA9641 will\ndisconnect master from downstream bus and takes away its grant if this\nregister bit is enabled. This IDLE_TIMER_DIS function also applies when there\nis a grant of a request with zero value on RES_TIME.\n\n- `false` -> Normal operation.\n- `true` -> Enable 100 ms idle timer. After reserve timer expires or if\n  reserve timer is disabled, if the downstream bus is idle for more than 100\n  ms, the connection between master and downstream bus will be disconnected.","ref":"PCA9641.html#idle_timer_disconnect?/1"},{"type":"function","title":"PCA9641.interrupt_clear/2","doc":"Clear specific interrupts from the interrupt status register","ref":"PCA9641.html#interrupt_clear/2"},{"type":"function","title":"PCA9641.interrupt_enable/2","doc":"Enable the specified interrupts.","ref":"PCA9641.html#interrupt_enable/2"},{"type":"function","title":"PCA9641.interrupt_enabled/1","doc":"Returns a list of atoms containing the","ref":"PCA9641.html#interrupt_enabled/1"},{"type":"function","title":"PCA9641.interrupt_in_interrupt_enabled?/1","doc":"INT_IN_MSK\n\n- `false` -> Enable output interrupt when INT_IN function is set.\n- `true` -> Disable output interrupt when INT_IN function is set.","ref":"PCA9641.html#interrupt_in_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.interrupt_pin_disable/1","doc":"Disable interrupts on the `int_pin`.\n\nDisables interrupts on the GPIO pin which is connected to the PCA9641\ninterrupt pin.","ref":"PCA9641.html#interrupt_pin_disable/1"},{"type":"function","title":"PCA9641.interrupt_pin_enable/1","doc":"Enable interrupts on the `int_pin`.\n\nEnables interrupts on the GPIO pin which is connected to the PCA9641 interrupt\npin.  The Wafer interrupt message metadata field will contain this PCA9641\nconn.","ref":"PCA9641.html#interrupt_pin_enable/1"},{"type":"function","title":"PCA9641.interrupt_pin_enable/2","doc":"Enable interrupts on the `int_pin`.\n\nEnables interrupts on the GPIO pin which is connected to the PCA9641 interrupt\npin.  The Wafer interrupt message metadata field will contain a two-tuple of\nthis PCA9641 conn and `metadata`.","ref":"PCA9641.html#interrupt_pin_enable/2"},{"type":"function","title":"PCA9641.interrupt_reason/1","doc":"Indicates the reasons for which an interrupt was generated (if any).","ref":"PCA9641.html#interrupt_reason/1"},{"type":"function","title":"PCA9641.interupt_in_interrupt?/1","doc":"INT_IN_INT\n\nIndicates that there is an interrupt from the downstream bus to both the\ngranted and non-granted masters.\n\n- `false` -> No interrupt on interrupt input pin INT_IN.\n- `true` -> Interrupt on interrupt input pin INT_IN.","ref":"PCA9641.html#interupt_in_interrupt?/1"},{"type":"function","title":"PCA9641.lock_grant?/1","doc":"LOCK_GRANT\n\nThis is a status read only register bit. Lock grant status register bit\nindicates the ownership between reading master and the downstream bus. If this\nregister bit is 1, the reading master has owned the downstream bus. If this\nregister bit is zero, the reading master has not owned the downstream bus.\n\n- `false` -> This master does not have a lock on the downstream bus.\n- `true` -> This master has a lock on the downstream bus.","ref":"PCA9641.html#lock_grant?/1"},{"type":"function","title":"PCA9641.lock_grant_interrupt?/1","doc":"LOCK_GRANT_INT\n\nIndicates the master has a lock (ownership) on the downstream bus.\n\n- `false` -> No interrupt generated; this master does not have a lock on the\n  downstream bus.\n- `true` -> Interrupt generated; this master has a lock on the downstream bus.","ref":"PCA9641.html#lock_grant_interrupt?/1"},{"type":"function","title":"PCA9641.lock_grant_interrupt_enabled?/1","doc":"LOCK_GRANT_MSK\n\n- `false` -> Enable output interrupt when LOCK_GRANT function is set.\n- `true` -> Disable output interrupt when LOCK_GRANT function is set.","ref":"PCA9641.html#lock_grant_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.lock_request/2","doc":"LOCK_REQ\n\nLock request register bit is for a master requesting the downstream bus when\nit does not have a lock on downstream bus. When a master has a lock on\ndownstream bus, it can give up the ownership by writing zero to LOCK_REQ\nregister bit. When LOCK_REQ becomes zero, LOCK_GRANT bit becomes zero and the\ninternal switch will be open.\n\n- `false` -> Master is not requesting a lock on the downstream bus or giving\n  up the lock if master had a lock on the downstream bus.\n- `true` -> Master is requesting a lock on the downstream bus.","ref":"PCA9641.html#lock_request/2"},{"type":"function","title":"PCA9641.lock_request?/1","doc":"LOCK_REQ\n\nLock request register bit is for a master requesting the downstream bus when\nit does not have a lock on downstream bus. When a master has a lock on\ndownstream bus, it can give up the ownership by writing zero to LOCK_REQ\nregister bit. When LOCK_REQ becomes zero, LOCK_GRANT bit becomes zero and the\ninternal switch will be open.\n\n- `false` -> Master is not requesting a lock on the downstream bus or giving\n  up the lock if master had a lock on the downstream bus.\n- `true` -> Master is requesting a lock on the downstream bus.","ref":"PCA9641.html#lock_request?/1"},{"type":"function","title":"PCA9641.mailbox_empty?/1","doc":"MBOX_EMPTY\n\nThis is a read-only status register bit. If this bit is ‘0’, it indicates\nother master mailbox is full, and this master cannot send more data to other\nmaster mailbox. If it is ‘1’, it indicates other master is empty and this\nmaster can send data to other master mailbox.\n\n- `false` -> *Other* master mailbox is full; wait until *other* master reads\n  data.\n- `true` -> *Other* master mailbox is empty. *Other* master has read previous\n  data and it is permitted to write new data.","ref":"PCA9641.html#mailbox_empty?/1"},{"type":"function","title":"PCA9641.mailbox_empty_interrupt?/1","doc":"MBOX_EMPTY_INT\n\nIndicates the sent mail is empty, other master has read the mail.\n\n- `false` -> No interrupt generated; sent mail is not empty.\n- `true` -> Interrupt generated; mailbox is empty.","ref":"PCA9641.html#mailbox_empty_interrupt?/1"},{"type":"function","title":"PCA9641.mailbox_empty_interrupt_enabled?/1","doc":"MBOX_EMPTY_MSK\n\n- `false` -> Enable output interrupt when MBOX_EMPTY function is set.\n- `true` -> Disable output interrupt when MBOX_EMPTY function is set.","ref":"PCA9641.html#mailbox_empty_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.mailbox_full?/1","doc":"MBOX_FULL\n\nThis is a read-only status register bit. If this bit is ‘0’, it indicates no\ndata is available in the mail box. If it is ‘1’, it indicates new data is\navailable in the mail box.\n\n- `false` -> No data is available for *this* master.\n- `true` -> Mailbox contains data for *this* master from the other master.","ref":"PCA9641.html#mailbox_full?/1"},{"type":"function","title":"PCA9641.mailbox_full_interrupt?/1","doc":"MBOX_FULL_INT\n\nIndicates the mailbox has new mail.\n\n- `false` -> No interrupt generated; mailbox is not full.\n- `true` -> Interrupt generated; mailbox full.","ref":"PCA9641.html#mailbox_full_interrupt?/1"},{"type":"function","title":"PCA9641.mailbox_full_interrupt_enabled?/1","doc":"MBOX_FULL_MSK\n\n- `false` -> Enable output interrupt when MBOX_FULL function is set.\n- `true` -> Disable output interrupt when MBOX_FULL function is set.","ref":"PCA9641.html#mailbox_full_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.other_lock?/1","doc":"OTHER_LOCK\n\nThis is a status read-only register bit. Other master lock status indicates\nthe ownership between other master and the downstream bus. If this register\nbit is ‘1’, the other master has owned the downstream bus. If this register\nbit is ‘0’, the other master does not own the downstream bus.\n\n- `false` -> The other master does not have a lock on the downstream bus.\n- `true` -> The other master has a lock on the downstream bus.","ref":"PCA9641.html#other_lock?/1"},{"type":"function","title":"PCA9641.priority/2","doc":"PRIORITY\n\nMaster can set this register bit for setting priority of the winner when two\nmasters request the downstream bus at the same time.","ref":"PCA9641.html#priority/2"},{"type":"function","title":"PCA9641.priority?/1","doc":"PRIORITY\n\nMaster can set this register bit for setting priority of the winner when two\nmasters request the downstream bus at the same time.","ref":"PCA9641.html#priority?/1"},{"type":"function","title":"PCA9641.read_mailbox/1","doc":"Read shared mailbox.","ref":"PCA9641.html#read_mailbox/1"},{"type":"function","title":"PCA9641.request_downstream_bus/1","doc":"Attempt to acquire the downstream I2C bus.","ref":"PCA9641.html#request_downstream_bus/1"},{"type":"function","title":"PCA9641.reserve_time/1","doc":"RES_TIME\n\nReserve timer. Changes during LOCK_GRANT = 1 will have no effect.\n\nReturns `{:ok, n}` where `n` is the number if milliseconds remaining in the\nreservation.","ref":"PCA9641.html#reserve_time/1"},{"type":"function","title":"PCA9641.reserve_time/2","doc":"RES_TIME\n\nReserve timer. Changes during LOCK_GRANT = 1 will have no effect.\n\n`ms` is the number of milliseconds remaining in the reservation.","ref":"PCA9641.html#reserve_time/2"},{"type":"function","title":"PCA9641.scl_becomes_io/2","doc":"SCL_IO\n\nSCL becomes I/O pin; master can read or write to this register bit. If master\nreads this bit, the value is the state of the downstream SCL pin. Zero value\nmeans SCL is LOW, and one means SCL pin is HIGH. When master writes ‘0’ to\nthis register bit, the downstream SCL pin will assert LOW. If master writes‘1’\nto this register bit, the downstream SCL pin will be pulled HIGH. Remark: SCL\nbecomes I/O pin only when BUS_CONNECT = 0 and LOCK_GRANT = 1.\n\n- `false` -> When read, shows the SCL pin of the downstream bus is LOW. When\n  written, PCA9641 drives SCL pin of downstream bus LOW.\n- `true` -> When read, shows the SCL pin of the downstream bus is HIGH. When\n  written, PCA9641 drives SCL pin of the downstream bus HIGH.","ref":"PCA9641.html#scl_becomes_io/2"},{"type":"function","title":"PCA9641.scl_becomes_io?/1","doc":"SCL_IO\n\nSCL becomes I/O pin; master can read or write to this register bit. If master\nreads this bit, the value is the state of the downstream SCL pin. Zero value\nmeans SCL is LOW, and one means SCL pin is HIGH. When master writes ‘0’ to\nthis register bit, the downstream SCL pin will assert LOW. If master writes‘1’\nto this register bit, the downstream SCL pin will be pulled HIGH. Remark: SCL\nbecomes I/O pin only when BUS_CONNECT = 0 and LOCK_GRANT = 1.\n\n- `false` -> When read, shows the SCL pin of the downstream bus is LOW. When\n  written, PCA9641 drives SCL pin of downstream bus LOW.\n- `true` -> When read, shows the SCL pin of the downstream bus is HIGH. When\n  written, PCA9641 drives SCL pin of the downstream bus HIGH.","ref":"PCA9641.html#scl_becomes_io?/1"},{"type":"function","title":"PCA9641.sda_becomes_io/2","doc":"SDA_IO\n\nSDA becomes I/O pin; master can read or write to this register bit. If master\nreads this bit, the value is the state of the downstream SDA pin. Zero value\nmeans SDA is LOW, and one means SDA pin is HIGH. When master writes ‘0’ to\nthis register bit, the downstream SDA pin will assert LOW. If master writes‘1’\nto this register bit, the downstream SDA pin will be pulled HIGH. Remark: SDA\nbecomes I/O pin only when BUS_CONNECT = 0 and LOCK_GRANT = 1.\n\n- `false` -> When read, indicates the SDA pin of the downstream bus is LOW.\n  When written, PCA9641 drives SDA pin of downstream bus LOW.\n- `true` -> When read, indicates the SDA pin of the downstream bus is HIGH.\n  When written, PCA9641 drives SDA pin of the downstream bus HIGH.","ref":"PCA9641.html#sda_becomes_io/2"},{"type":"function","title":"PCA9641.sda_becomes_io?/1","doc":"SDA_IO\n\nSDA becomes I/O pin; master can read or write to this register bit. If master\nreads this bit, the value is the state of the downstream SDA pin. Zero value\nmeans SDA is LOW, and one means SDA pin is HIGH. When master writes ‘0’ to\nthis register bit, the downstream SDA pin will assert LOW. If master writes‘1’\nto this register bit, the downstream SDA pin will be pulled HIGH. Remark: SDA\nbecomes I/O pin only when BUS_CONNECT = 0 and LOCK_GRANT = 1.\n\n- `false` -> When read, indicates the SDA pin of the downstream bus is LOW.\n  When written, PCA9641 drives SDA pin of downstream bus LOW.\n- `true` -> When read, indicates the SDA pin of the downstream bus is HIGH.\n  When written, PCA9641 drives SDA pin of the downstream bus HIGH.","ref":"PCA9641.html#sda_becomes_io?/1"},{"type":"function","title":"PCA9641.smbus_software_reset/2","doc":"SMBUS_SWRST\n\nNon-granted or granted master sends a soft reset, if this bit is set, PCA9641\nsets clock LOW for 35 ms following reset of all register values to defaults.\n\n- `false` -> Normal operation.\n- `true` -> Enable sending SMBus time-out to downstream bus, after receiving a\n  general call soft reset from master.","ref":"PCA9641.html#smbus_software_reset/2"},{"type":"function","title":"PCA9641.smbus_software_reset?/1","doc":"SMBUS_SWRST\n\nNon-granted or granted master sends a soft reset, if this bit is set, PCA9641\nsets clock LOW for 35 ms following reset of all register values to defaults.\n\n- `false` -> Normal operation.\n- `true` -> Enable sending SMBus time-out to downstream bus, after receiving a\n  general call soft reset from master.","ref":"PCA9641.html#smbus_software_reset?/1"},{"type":"function","title":"PCA9641.test_interrupt_interrupt_enabled?/1","doc":"TEST_INT_MSK\n\n- `false` -> Enable output interrupt when TEST_INT function is set.\n- `true` -> Disable output interrupt when TEST_INT function is set.","ref":"PCA9641.html#test_interrupt_interrupt_enabled?/1"},{"type":"function","title":"PCA9641.test_interrupt_pin/2","doc":"TEST_INT\n\nTest interrupt output pin; a master can send an interrupt to itself by writing\n‘1’ to this register bit. Writing ‘0’ to this register bit has no effect. To\nclear this interrupt, master must write ‘1’ to TEST_INT_INT in Interrupt\nStatus register.\n\n- `false` -> Normal operation.\n- `true` -> Causes PCA9641 INT pin to go LOW if not masked by TEST_INT_INT in\n  Interrupt Mask register. Allows this master to invoke its Interrupt Service\n  Routine to handle housekeeping tasks.","ref":"PCA9641.html#test_interrupt_pin/2"},{"type":"function","title":"PCA9641.test_interrupt_pin?/1","doc":"TEST_INT\n\nTest interrupt output pin; a master can send an interrupt to itself by writing\n‘1’ to this register bit. Writing ‘0’ to this register bit has no effect. To\nclear this interrupt, master must write ‘1’ to TEST_INT_INT in Interrupt\nStatus register.\n\n- `false` -> Normal operation.\n- `true` -> Causes PCA9641 INT pin to go LOW if not masked by TEST_INT_INT in\n  Interrupt Mask register. Allows this master to invoke its Interrupt Service\n  Routine to handle housekeeping tasks.","ref":"PCA9641.html#test_interrupt_pin?/1"},{"type":"function","title":"PCA9641.test_interrupt_pin_interrupt?/1","doc":"TEST_INT_INT\n\nIndicates this master has sent an interrupt to itself.\n\n- `false` -> No interrupt generated; master has not set the TEST_INT bit in\n  STATUS register.\n- `true` -> Interrupt generated; master activates its interrupt pin via the\n  TEST_INT bit in STATUS register.","ref":"PCA9641.html#test_interrupt_pin_interrupt?/1"},{"type":"function","title":"PCA9641.verify_identity/1","doc":"Verify the contents of the identity register.\n\nIt should match the expected value of `56`.","ref":"PCA9641.html#verify_identity/1"},{"type":"function","title":"PCA9641.wait_for_bus_init/1","doc":"Waits for downstream bus initialisation to succeed.\n\nWaits for a maximum of 1 second.","ref":"PCA9641.html#wait_for_bus_init/1"},{"type":"function","title":"PCA9641.write_mailbox/2","doc":"Write shared mailbox.","ref":"PCA9641.html#write_mailbox/2"},{"type":"type","title":"PCA9641.acquire_option/0","doc":"","ref":"PCA9641.html#t:acquire_option/0"},{"type":"type","title":"PCA9641.acquire_options/0","doc":"","ref":"PCA9641.html#t:acquire_options/0"},{"type":"type","title":"PCA9641.interrupt_name/0","doc":"","ref":"PCA9641.html#t:interrupt_name/0"},{"type":"type","title":"PCA9641.mailbox_data/0","doc":"","ref":"PCA9641.html#t:mailbox_data/0"},{"type":"type","title":"PCA9641.t/0","doc":"","ref":"PCA9641.html#t:t/0"},{"type":"module","title":"PCA9641.Registers","doc":"This module provides a wrapper around the PCA9641 registers described in NXP's\ndatasheet.","ref":"PCA9641.Registers.html"},{"type":"function","title":"PCA9641.Registers.read_control/1","doc":"Read the contents of the `control` register.","ref":"PCA9641.Registers.html#read_control/1"},{"type":"function","title":"Example - PCA9641.Registers.read_control/1","doc":"iex> read_control(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_control/1-example"},{"type":"function","title":"PCA9641.Registers.read_id/1","doc":"Read the contents of the `id` register.","ref":"PCA9641.Registers.html#read_id/1"},{"type":"function","title":"Example - PCA9641.Registers.read_id/1","doc":"iex> read_id(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_id/1-example"},{"type":"function","title":"PCA9641.Registers.read_interrupt_mask/1","doc":"Read the contents of the `interrupt_mask` register.","ref":"PCA9641.Registers.html#read_interrupt_mask/1"},{"type":"function","title":"Example - PCA9641.Registers.read_interrupt_mask/1","doc":"iex> read_interrupt_mask(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_interrupt_mask/1-example"},{"type":"function","title":"PCA9641.Registers.read_interrupt_status/1","doc":"Read the contents of the `interrupt_status` register.","ref":"PCA9641.Registers.html#read_interrupt_status/1"},{"type":"function","title":"Example - PCA9641.Registers.read_interrupt_status/1","doc":"iex> read_interrupt_status(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_interrupt_status/1-example"},{"type":"function","title":"PCA9641.Registers.read_mailbox_lsb/1","doc":"Read the contents of the `mailbox_lsb` register.","ref":"PCA9641.Registers.html#read_mailbox_lsb/1"},{"type":"function","title":"Example - PCA9641.Registers.read_mailbox_lsb/1","doc":"iex> read_mailbox_lsb(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_mailbox_lsb/1-example"},{"type":"function","title":"PCA9641.Registers.read_mailbox_msb/1","doc":"Read the contents of the `mailbox_msb` register.","ref":"PCA9641.Registers.html#read_mailbox_msb/1"},{"type":"function","title":"Example - PCA9641.Registers.read_mailbox_msb/1","doc":"iex> read_mailbox_msb(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_mailbox_msb/1-example"},{"type":"function","title":"PCA9641.Registers.read_reserve_time/1","doc":"Read the contents of the `reserve_time` register.","ref":"PCA9641.Registers.html#read_reserve_time/1"},{"type":"function","title":"Example - PCA9641.Registers.read_reserve_time/1","doc":"iex> read_reserve_time(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_reserve_time/1-example"},{"type":"function","title":"PCA9641.Registers.read_status/1","doc":"Read the contents of the `status` register.","ref":"PCA9641.Registers.html#read_status/1"},{"type":"function","title":"Example - PCA9641.Registers.read_status/1","doc":"iex> read_status(conn)\n    {:ok,  >}","ref":"PCA9641.Registers.html#read_status/1-example"},{"type":"function","title":"PCA9641.Registers.swap_control/2","doc":"Swap the contents of the `control` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_control/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_control/2","doc":"iex> swap_control(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_control/2-example"},{"type":"function","title":"PCA9641.Registers.swap_interrupt_mask/2","doc":"Swap the contents of the `interrupt_mask` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_interrupt_mask/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_interrupt_mask/2","doc":"iex> swap_interrupt_mask(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_interrupt_mask/2-example"},{"type":"function","title":"PCA9641.Registers.swap_interrupt_status/2","doc":"Swap the contents of the `interrupt_status` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_interrupt_status/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_interrupt_status/2","doc":"iex> swap_interrupt_status(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_interrupt_status/2-example"},{"type":"function","title":"PCA9641.Registers.swap_mailbox_lsb/2","doc":"Swap the contents of the `mailbox_lsb` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_mailbox_lsb/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_mailbox_lsb/2","doc":"iex> swap_mailbox_lsb(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_mailbox_lsb/2-example"},{"type":"function","title":"PCA9641.Registers.swap_mailbox_msb/2","doc":"Swap the contents of the `mailbox_msb` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_mailbox_msb/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_mailbox_msb/2","doc":"iex> swap_mailbox_msb(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_mailbox_msb/2-example"},{"type":"function","title":"PCA9641.Registers.swap_reserve_time/2","doc":"Swap the contents of the `reserve_time` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_reserve_time/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_reserve_time/2","doc":"iex> swap_reserve_time(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_reserve_time/2-example"},{"type":"function","title":"PCA9641.Registers.swap_status/2","doc":"Swap the contents of the `status` register.\n\nReads the contents of the register, then replaces it, returning the\nprevious contents.  Some drivers may implement this atomically.","ref":"PCA9641.Registers.html#swap_status/2"},{"type":"function","title":"Example - PCA9641.Registers.swap_status/2","doc":"iex> swap_status(conn,  >)\n    {:ok,  >, _conn}","ref":"PCA9641.Registers.html#swap_status/2-example"},{"type":"function","title":"PCA9641.Registers.update_control/2","doc":"Update the contents of the `control` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_control/2"},{"type":"function","title":"Example - PCA9641.Registers.update_control/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_control(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_control/2-example"},{"type":"function","title":"PCA9641.Registers.update_interrupt_mask/2","doc":"Update the contents of the `interrupt_mask` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_interrupt_mask/2"},{"type":"function","title":"Example - PCA9641.Registers.update_interrupt_mask/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_interrupt_mask(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_interrupt_mask/2-example"},{"type":"function","title":"PCA9641.Registers.update_interrupt_status/2","doc":"Update the contents of the `interrupt_status` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_interrupt_status/2"},{"type":"function","title":"Example - PCA9641.Registers.update_interrupt_status/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_interrupt_status(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_interrupt_status/2-example"},{"type":"function","title":"PCA9641.Registers.update_mailbox_lsb/2","doc":"Update the contents of the `mailbox_lsb` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_mailbox_lsb/2"},{"type":"function","title":"Example - PCA9641.Registers.update_mailbox_lsb/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_mailbox_lsb(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_mailbox_lsb/2-example"},{"type":"function","title":"PCA9641.Registers.update_mailbox_msb/2","doc":"Update the contents of the `mailbox_msb` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_mailbox_msb/2"},{"type":"function","title":"Example - PCA9641.Registers.update_mailbox_msb/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_mailbox_msb(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_mailbox_msb/2-example"},{"type":"function","title":"PCA9641.Registers.update_reserve_time/2","doc":"Update the contents of the `reserve_time` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_reserve_time/2"},{"type":"function","title":"Example - PCA9641.Registers.update_reserve_time/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_reserve_time(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_reserve_time/2-example"},{"type":"function","title":"PCA9641.Registers.update_status/2","doc":"Update the contents of the `status` register using a\ntransformation function.","ref":"PCA9641.Registers.html#update_status/2"},{"type":"function","title":"Example - PCA9641.Registers.update_status/2","doc":"iex> transform = fn  > ->  > end\n    ...> update_status(conn, transform)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#update_status/2-example"},{"type":"function","title":"PCA9641.Registers.write_control/2","doc":"Write new contents to the `control` register.","ref":"PCA9641.Registers.html#write_control/2"},{"type":"function","title":"Example - PCA9641.Registers.write_control/2","doc":"iex> write_control(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_control/2-example"},{"type":"function","title":"PCA9641.Registers.write_interrupt_mask/2","doc":"Write new contents to the `interrupt_mask` register.","ref":"PCA9641.Registers.html#write_interrupt_mask/2"},{"type":"function","title":"Example - PCA9641.Registers.write_interrupt_mask/2","doc":"iex> write_interrupt_mask(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_interrupt_mask/2-example"},{"type":"function","title":"PCA9641.Registers.write_interrupt_status/2","doc":"Write new contents to the `interrupt_status` register.","ref":"PCA9641.Registers.html#write_interrupt_status/2"},{"type":"function","title":"Example - PCA9641.Registers.write_interrupt_status/2","doc":"iex> write_interrupt_status(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_interrupt_status/2-example"},{"type":"function","title":"PCA9641.Registers.write_mailbox_lsb/2","doc":"Write new contents to the `mailbox_lsb` register.","ref":"PCA9641.Registers.html#write_mailbox_lsb/2"},{"type":"function","title":"Example - PCA9641.Registers.write_mailbox_lsb/2","doc":"iex> write_mailbox_lsb(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_mailbox_lsb/2-example"},{"type":"function","title":"PCA9641.Registers.write_mailbox_msb/2","doc":"Write new contents to the `mailbox_msb` register.","ref":"PCA9641.Registers.html#write_mailbox_msb/2"},{"type":"function","title":"Example - PCA9641.Registers.write_mailbox_msb/2","doc":"iex> write_mailbox_msb(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_mailbox_msb/2-example"},{"type":"function","title":"PCA9641.Registers.write_reserve_time/2","doc":"Write new contents to the `reserve_time` register.","ref":"PCA9641.Registers.html#write_reserve_time/2"},{"type":"function","title":"Example - PCA9641.Registers.write_reserve_time/2","doc":"iex> write_reserve_time(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_reserve_time/2-example"},{"type":"function","title":"PCA9641.Registers.write_status/2","doc":"Write new contents to the `status` register.","ref":"PCA9641.Registers.html#write_status/2"},{"type":"function","title":"Example - PCA9641.Registers.write_status/2","doc":"iex> write_status(conn,  >)\n    {:ok, _conn}","ref":"PCA9641.Registers.html#write_status/2-example"},{"type":"extras","title":"PCA9641","doc":"# PCA9641\n\n[![Build Status](https://drone.harton.dev/api/badges/james/pca9641/status.svg)](https://drone.harton.dev/james/pca9641)\n[![Hex.pm](https://img.shields.io/hexpm/v/pca9641.svg)](https://hex.pm/packages/pca9641)\n[![Hippocratic License HL3-FULL](https://img.shields.io/static/v1?label=Hippocratic%20License&message=HL3-FULL&labelColor=5e2751&color=bc8c3d)](https://firstdonoharm.dev/version/3/0/full.html)\n\nDriver for the PCA9641 2-channel I2C bus master arbiter chip.\n\nIt's a pretty sweet little chip that lets you connect two i2c mastering devices\nto a shared downstream bus and makes sure that only one master can address the\ndownstream devices at a time. It can also relay downstream interrupts to the\nmastering devices.","ref":"readme.html"},{"type":"extras","title":"Installation - PCA9641","doc":"`pca9641` is [available in Hex](https://hex.pm/packages/pca9641), the package\ncan be installed by adding `pca9641` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pca9641, \"~> 2.0.1\"}\n  ]\nend\n```\n\nDocumentation for the latest release can be found on\n[HexDocs](https://hexdocs.pm/pca9641) and for the `main` branch on\n[docs.harton.nz](https://docs.harton.nz/james/pca9641).","ref":"readme.html#installation"},{"type":"extras","title":"Github Mirror - PCA9641","doc":"This repository is mirrored [on Github](https://github.com/jimsynz/pca9641)\nfrom it's primary location [on my Forejo instance](https://harton.dev/james/pca9641).\nFeel free to raise issues and open PRs on Github.","ref":"readme.html#github-mirror"},{"type":"extras","title":"License - PCA9641","doc":"This software is licensed under the terms of the\n[HL3-FULL](https://firstdonoharm.dev), see the `LICENSE.md` file included with\nthis package for the terms.\n\nThis license actively proscribes this software being used by and for some\nindustries, countries and activities. If your usage of this software doesn't\ncomply with the terms of this license, then [contact me](mailto:james@harton.nz)\nwith the details of your use-case to organise the purchase of a license - the\ncost of which may include a donation to a suitable charity or NGO.","ref":"readme.html#license"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n \n\n## [v2.0.1](https://harton.dev/james/pca9641/compare/v2.0.0...v2.0.1) (2024-02-23)\n\n\n\n\n## [v2.0.0](https://harton.dev/james/pca9641/compare/v1.0.0...v2.0.0) (2023-01-16)\n\n#","ref":"changelog.html"},{"type":"extras","title":"Breaking Changes: - Change Log","doc":"- Relicence to HL3-FULL.\n\n## [v1.0.0](https://harton.dev/james/pca9641/compare/v1.0.0...v1.0.0) (2020-12-28)","ref":"changelog.html#breaking-changes"}],"content_type":"text/markdown"}